summaryrefslogtreecommitdiff
path: root/src/reel_picture_asset.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/reel_picture_asset.h')
-rw-r--r--src/reel_picture_asset.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/reel_picture_asset.h b/src/reel_picture_asset.h
index 0c167045..6185f3dd 100644
--- a/src/reel_picture_asset.h
+++ b/src/reel_picture_asset.h
@@ -54,17 +54,17 @@ namespace dcp {
class ReelPictureAsset : public ReelFileAsset
{
public:
- ReelPictureAsset (std::shared_ptr<PictureAsset> asset, int64_t entry_point);
+ ReelPictureAsset (std::shared_ptr<J2KPictureAsset> asset, int64_t entry_point);
explicit ReelPictureAsset (std::shared_ptr<const cxml::Node>);
- /** @return the PictureAsset that this object refers to */
- std::shared_ptr<const PictureAsset> asset () const {
- return asset_of_type<const PictureAsset>();
+ /** @return the J2KPictureAsset that this object refers to */
+ std::shared_ptr<const J2KPictureAsset> asset () const {
+ return asset_of_type<const J2KPictureAsset>();
}
- /** @return the PictureAsset that this object refers to */
- std::shared_ptr<PictureAsset> asset () {
- return asset_of_type<PictureAsset>();
+ /** @return the J2KPictureAsset that this object refers to */
+ std::shared_ptr<J2KPictureAsset> asset () {
+ return asset_of_type<J2KPictureAsset>();
}
virtual xmlpp::Element* write_to_cpl(xmlpp::Element* node, Standard standard) const override;